package javax.sound.sampled;

import java.util.EventObject;

public class LineEvent extends EventObject
{
    private final LineEvent.Type type;
    private final long position;
    
    public LineEvent(Line source, LineEvent.Type type, long position) {
        super(source);
        this.type = type;
        this.position = position;
    }
    
    public final Line getLine() {
        return (Line)this.getSource();
    }
    
    public final LineEvent.Type getType() {
        return this.type;
    }
    
    public final long getFramePosition() {
        return this.position;
    }
    
    @Override
    public String toString() {
        String string = "";
        if (this.type != null) {
            string = this.type.toString() + " ";
        }
        String string2;
        if (this.getLine() == null) {
            string2 = "null";
        }
        else {
            string2 = this.getLine().toString();
        }
        return new String(string + "event from line " + string2);
    }
    
    public static class Type
    {
        private String name;
        public static final LineEvent.Type OPEN;
        public static final LineEvent.Type CLOSE;
        public static final LineEvent.Type START;
        public static final LineEvent.Type STOP;
        
        protected Type(String name) {
            this.name = name;
        }
        
        @Override
        public final boolean equals(Object obj) {
            return super.equals(obj);
        }
        
        @Override
        public final int hashCode() {
            return super.hashCode();
        }
        
        @Override
        public String toString() {
            return this.name;
        }
        
        static {
            OPEN = new LineEvent.Type("Open");
            CLOSE = new LineEvent.Type("Close");
            START = new LineEvent.Type("Start");
            STOP = new LineEvent.Type("Stop");
        }
    }
}
